Welcome to dogpile.cache’s documentation! — dogpile.cache 0.5.5 documentation

### Navigation

- index
- modules |
- next |
- dogpile.cache 0.5.5 documentation »

# Welcome to dogpile.cache’s documentation!

dogpile.cache provides a simple caching pattern based on the dogpile.core locking system, including rudimentary backends. It effectively completes the replacement of Beaker as far as caching (though not HTTP sessions) is concerned, providing an open-ended, simple, and higher-performing pattern to configure and use cache backends. New backends are very easy to create and use; users are encouraged to adapt the provided backends for their own needs, as high volume caching requires lots of tweaks and adjustments specific to an application and its environment.

- Front Matter
  - Project Homepage
  - Installation
  - Community
  - Bugs
- Usage Guide
  - Overview
  - Rudimentary Usage
  - Region Configuration
  - Using a Region
  - Creating Backends
  - Changing Backend Behavior
  - Recipes
- API
  - Region
  - Backend API
  - Backends
  - Plugins
  - Utilities
- Changelog
  - 0.5.5
  - 0.5.4
  - 0.5.3
  - 0.5.2
  - 0.5.1
  - 0.5.0
  - 0.4.3
  - 0.4.2
  - 0.4.1
  - 0.4.0
  - 0.3.1
  - 0.3.0
  - 0.2.4
  - 0.2.3
  - 0.2.2
  - 0.2.1
  - 0.2.0
  - 0.1.1
  - 0.1.0

## Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- next |
- dogpile.cache 0.5.5 documentation »